
Welcome to Makina Django OIDC's documentation!
==============================================


.. toctree::
   :maxdepth: 2
   :caption: 🚀 Tutorials

   tutorial

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: 🪄 How-to guides

   how-to


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: 💡 Explanation

   explanation


.. toctree::
   :maxdepth: 4
   :hidden:
   :caption: 📚 Reference

   user.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
